@@ -9,33 +9,74 @@
 #'
 #' @return Vector of color values from specified palette.
 #'
+#' @keywords internal
+#'
 #' @name paleteer-c-wrapper
 #' @rdname paleteer-c-wrapper
 paletteer_c_ggthemes <- function(name, n) {
   check_installed("ggthemes")
 
   ggthemes_c_seq_names <- c(
-    "Blue-Green Sequential", "Blue Light", "Orange Light", "Blue", "Orange",
-    "Green", "Red", "Purple", "Brown", "Gray", "Gray Warm", "Blue-Teal",
-    "Orange-Gold", "Green-Gold", "Red-Gold", "Classic Green", "Classic Gray",
-    "Classic Blue", "Classic Red", "Classic Orange", "Classic Area Red",
-    "Classic Area Green", "Classic Area-Brown"
+    "Blue-Green Sequential",
+    "Blue Light",
+    "Orange Light",
+    "Blue",
+    "Orange",
+    "Green",
+    "Red",
+    "Purple",
+    "Brown",
+    "Gray",
+    "Gray Warm",
+    "Blue-Teal",
+    "Orange-Gold",
+    "Green-Gold",
+    "Red-Gold",
+    "Classic Green",
+    "Classic Gray",
+    "Classic Blue",
+    "Classic Red",
+    "Classic Orange",
+    "Classic Area Red",
+    "Classic Area Green",
+    "Classic Area-Brown"
   )
 
   ggthemes_c_div_names <- c(
-    "Orange-Blue Diverging", "Red-Green Diverging", "Green-Blue Diverging",
-    "Red-Blue Diverging", "Red-Black Diverging", "Gold-Purple Diverging",
-    "Red-Green-Gold Diverging", "Sunset-Sunrise Diverging", "Orange-Blue-White Diverging",
-    "Red-Green-White Diverging", "Green-Blue-White Diverging", "Red-Blue-White Diverging",
-    "Red-Black-White Diverging", "Orange-Blue Light Diverging", "Temperature Diverging",
-    "Classic Red-Green", "Classic Red-Blue", "Classic Red-Black", "Classic Area Red-Green",
-    "Classic Orange-Blue", "Classic Green-Blue", "Classic Red-White-Green",
-    "Classic Red-White-Black", "Classic Orange-White-Blue", "Classic Red-White-Black Light",
-    "Classic Orange-White-Blue Light", "Classic Red-White-Green Light",
+    "Orange-Blue Diverging",
+    "Red-Green Diverging",
+    "Green-Blue Diverging",
+    "Red-Blue Diverging",
+    "Red-Black Diverging",
+    "Gold-Purple Diverging",
+    "Red-Green-Gold Diverging",
+    "Sunset-Sunrise Diverging",
+    "Orange-Blue-White Diverging",
+    "Red-Green-White Diverging",
+    "Green-Blue-White Diverging",
+    "Red-Blue-White Diverging",
+    "Red-Black-White Diverging",
+    "Orange-Blue Light Diverging",
+    "Temperature Diverging",
+    "Classic Red-Green",
+    "Classic Red-Blue",
+    "Classic Red-Black",
+    "Classic Area Red-Green",
+    "Classic Orange-Blue",
+    "Classic Green-Blue",
+    "Classic Red-White-Green",
+    "Classic Red-White-Black",
+    "Classic Orange-White-Blue",
+    "Classic Red-White-Black Light",
+    "Classic Orange-White-Blue Light",
+    "Classic Red-White-Green Light",
     "Classic Red-Green Light"
   )
 
-  name <- try(match.arg(name, c(ggthemes_c_seq_names, ggthemes_c_div_names)), silent = T)
+  name <- try(
+    match.arg(name, c(ggthemes_c_seq_names, ggthemes_c_div_names)),
+    silent = T
+  )
 
   if (name %in% ggthemes_c_seq_names) {
     pal_gen <- ggthemes::tableau_seq_gradient_pal(palette = name)
@@ -48,10 +89,16 @@ paletteer_c_ggthemes <- function(name, n) {
 
 #' @rdname paleteer-c-wrapper
 paletteer_c_grDevices <- function(name, n) {
-  if (name %in% c(
-    "rainbow", "heat.colors", "terrain.colors",
-    "topo.colors", "cm.colors"
-  )) {
+  if (
+    name %in%
+      c(
+        "rainbow",
+        "heat.colors",
+        "terrain.colors",
+        "topo.colors",
+        "cm.colors"
+      )
+  ) {
     pal_gen <- getExportedValue("grDevices", name)
 
     return(pal_gen(n = n))
@@ -121,12 +168,12 @@ NULL
 
 wrapper_c <- list(
   # gameofthrones = paletteer_c_gameofthrones,
-  ggthemes      = paletteer_c_ggthemes,
-  grDevices     = paletteer_c_grDevices,
-  harrypotter   = paletteer_c_harrypotter,
-  oompaBase     = paletteer_c_oompaBase,
-  palr          = paletteer_c_palr,
-  pals          = paletteer_c_pals,
-  scico         = paletteer_c_scico,
-  viridis       = paletteer_c_viridis
+  ggthemes = paletteer_c_ggthemes,
+  grDevices = paletteer_c_grDevices,
+  harrypotter = paletteer_c_harrypotter,
+  oompaBase = paletteer_c_oompaBase,
+  palr = paletteer_c_palr,
+  pals = paletteer_c_pals,
+  scico = paletteer_c_scico,
+  viridis = paletteer_c_viridis
 )
