@@ -9,11 +9,14 @@ test_that("paletteer_dynamic returns characters", {
 })
 
 test_that("paletteer_dynamic returns something when n is unspecified", {
-  expect_error(paletteer_dynamic("ggthemes_solarized::green"))
+  expect_snapshot(error = TRUE, paletteer_dynamic("ggthemes_solarized::green"))
 })
 
 test_that("paletteer_dynamic throws an error when n is specified too high", {
-  expect_error(paletteer_dynamic("ggthemes_solarized::green", 100))
+  expect_snapshot(
+    error = TRUE,
+    paletteer_dynamic("ggthemes_solarized::green", 100)
+  )
 })
 
 test_that("direction works correctly in paletteer_dynamic", {
@@ -25,7 +28,14 @@ test_that("direction works correctly in paletteer_dynamic", {
     paletteer_dynamic("ggthemes_solarized::green", 3, direction = -1),
     prismatic::color(c("#268bd2", "#dc322f", "#859900"))
   )
-  expect_error(paletteer_dynamic("ggthemes_solarized::green", 3, direction = 10))
+  expect_snapshot(
+    error = TRUE,
+    paletteer_dynamic(
+      "ggthemes_solarized::green",
+      3,
+      direction = 10
+    )
+  )
 })
 
 test_that("paletteer_dynamic works with quoted palettes", {
